Coverage report

|  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | ---
File |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
privacyforms_pdf / __init__.py |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py |  | 100% | 141 | 0 | 2 |  | 100% | 30 | 0 |  | 100%
privacyforms_pdf / extractor.py |  | 98% | 325 | 8 | 2 |  | 91% | 130 | 8 |  | 96%
Total |  | 98% | 469 | 8 | 4 |  | 92% | 160 | 8 |  | 97%

No items found using the specified filter.